@@ -1,11 +1,18 @@
 from typing import List
 
 import pandas as pd
+import re
+from datetime import date
 from sqlalchemy import engine, inspect
 from sqlalchemy.exc import SQLAlchemyError
 
 from aqueduct_executor.operators.connectors.tabular import connector, extract, load
 
+# Regular Expression that matches any substring apperance with
+# "{{ }}" and a word inside with optional space in front or after
+# Potential Matches: "{{today}}", "{{ today  }}""
+TAG_PATTERN = r"{{[\s+]*\w+[\s+]*}}"
+
 
 class RelationalConnector(connector.TabularConnector):
     def __init__(self, conn_engine: engine.Engine):
@@ -24,7 +31,15 @@ class RelationalConnector(connector.TabularConnector):
         return inspect(self.engine).get_table_names()
 
     def extract(self, params: extract.RelationalParams) -> pd.DataFrame:
-        df = pd.read_sql(params.query, con=self.engine)
+        query = params.query
+        matches = re.findall(TAG_PATTERN, query)
+        for match in matches:
+            tag = match.strip(" " "{}")
+            if tag == "today":
+                today_python = date.today()
+                today_sql = "'" + today_python.strftime("%Y-%m-%d") + "'"
+                query = query.replace("{{today}}", today_sql)
+        df = pd.read_sql(query, con=self.engine)
         return df
 
     def load(self, params: load.RelationalParams, df: pd.DataFrame) -> None:
